# FACT Rail Stations and Lines

Rail stations (passengers and freigth) and working rail lines in Europe and North America from OSM.

---

[![GitLab License](https://img.shields.io/gitlab/license/fact%2Fdata%2FFACT_rail?gitlab_url=https%3A%2F%2Fgit.nilu.no&style=flat&color=orange)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html)
[![DOI](https://img.shields.io/badge/DOI-10.17605%2FOSF.IO%2FCUJ65-blue?style=flat)](https://doi.org/10.17605/OSF.IO/CUJ65)
[![Data License](https://img.shields.io/badge/data-ODbL%20v1.0-green)](https://opendatacommons.org/licenses/odbl/1-0/)

---

## Use
1. Through the command line:
```bash
docker pull registry.git.nilu.no/fact/data/fact_rail:latest
docker run -t -i --name fact_rail -e MARIADB_DATABASE=FACT_rail -e MYSQL_ROOT_PASSWORD=devops -p 3311:3306 -d registry.git.nilu.no/fact/data/fact_rail:0.1
```
2. Through a docker-compose file:
```yaml
version: '3.8'

services:
  fact_rail:
    image: registry.git.nilu.no/fact/data/fact_rail:latest
    container_name: fact_rail
    environment:
      MARIADB_DATABASE: FACT_rail
      MYSQL_ROOT_PASSWORD: devops
    ports:
      - "3311:3306"
    restart: unless-stopped
```
which could be executed with `docker-compose up fact_rail -d`.

The container makes available a MariaDB instance with the full database on the rail system **FACT_rail**. It is reachable on port 3311 of the localhost and the root password is 'devops'.

---
## Specifications

```
Table           |Size (MB)|Rows (#)|
----------------+---------+--------+
eu_lines        |   777.08| 1172918|
eu_stations     |    14.98|   30049|
geometry_columns|     0.02|       4|
na_lines        |   231.65|  449237|
na_stations     |     1.13|    3734|
spatial_ref_sys |     0.02|       0|
```

![tables schema](FACT_rail.png "Tables in DB")

**All spatial objects are converted to EPSG:4326**

---
## Notes
OSM maps for Europe and North America are downloaded form https://download.geofabrik.de/

Tag filtering is used to select rail lines and stations, and then data is transformed to .geojson and uploaded in the database server.

To manipulate and transform data, we use https://osmcode.org/osmium-tool/

---
## Author
Riccardo Boero - ribo@nilu.no

## License
All the code and the resulting docker images in this project are subject to:
- [GNU General Public License v2](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).

The data is licensed under:
- the Open Data Commons Open Database License [(ODbL) v1.0](https://opendatacommons.org/licenses/odbl/1-0/).

## Citation
- Boero, Riccardo. 2024. “FACT Data: Buildings Footprint and Height.” OSF. [doi:10.17605/OSF.IO/CUJ65](https://doi.org/10.17605/OSF.IO/CUJ65).

Part of the Fine scAle eConomic daTa - FACT project:
- Boero, Riccardo. 2024. “Fine scAle eConomic daTa - FACT.” OSF. [doi:10.17605/OSF.IO/PV4ZW](https://doi.org/10.17605/OSF.IO/PV4ZW). 
