#!/bin/bash 

# Assign parameters to variables 
HOST=$1 
USER=$2 
PASSWORD=$3 

# create a temp dir
mkdir -p temp

# Europe
# download maps from http://download.geofabrik.de/
wget http://download.geofabrik.de/europe-latest.osm.pbf -P temp
# export rail lines
osmium tags-filter temp/europe-latest.osm.pbf w/railway=rail -o temp/line_europe.pbf --overwrite
osmium export temp/line_europe.pbf --geometry-types=linestring -o temp/line_europe.geojson --overwrite
# export stations
osmium tags-filter temp/europe-latest.osm.pbf n/railway=station -R -o temp/station_europe.pbf --overwrite
osmium tags-filter temp/station_europe.pbf n/subway=yes -R -o temp/subway_europe.pbf --overwrite
osmium cat temp/station_europe.pbf -o temp/station_europe.osm
osmium cat temp/subway_europe.pbf -o temp/subway_europe.osm
grep '<node' temp/subway_europe.osm | awk -F ' id="' '{print $2}' | awk -F '"' '{print $1}' > temp/exclude_europe_subway_ids.txt
awk '
BEGIN {
    while (getline < "temp/exclude_europe_subway_ids.txt") exclude[$1] = 1;
    inNode = 0;
    print "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"; # Ensure the XML header is included
    print "<osm version=\"0.6\" generator=\"osmium/1.8.0\">"; # Adjust osmium version as needed
}
/^ *<node / {
    split($0, a, / id="|"/);
    nodeId = a[2];
    inNode = !(nodeId in exclude);
}
inNode { print }
/^ *<\/node>/ { inNode = 0; }
END {
    print "</osm>";
}
' temp/station_europe.osm > temp/station_europe-filtered.osm
osmium cat temp/station_europe-filtered.osm -o temp/station_europe-filtered.osm.pbf
osmium export temp/station_europe-filtered.osm.pbf -o temp/station_europe.geojson --overwrite
# load in DB
ogr2ogr -f MySQL MySQL:FACT_rail,host=$HOST,user=$USER,password=$PASSWORD ./temp/station_europe.geojson -nln eu_stations -update -overwrite -lco engine=Aria -t_srs EPSG:4326
ogr2ogr -f MySQL MySQL:FACT_rail,host=$HOST,user=$USER,password=$PASSWORD ./temp/line_europe.geojson -nln eu_lines -update -overwrite -lco engine=Aria -t_srs EPSG:4326
#clean
rm temp/*.*

# North America
# download maps from http://download.geofabrik.de/
wget http://download.geofabrik.de/north-america-latest.osm.pbf -P temp
osmium tags-filter temp/north-america-latest.osm.pbf w/railway=rail -o temp/line_north-america.pbf --overwrite
osmium export temp/line_north-america.pbf --geometry-types=linestring -o temp/line_north-america.geojson --overwrite
# export stations
osmium tags-filter temp/north-america-latest.osm.pbf n/railway=station -R -o temp/station_north-america.pbf --overwrite
osmium tags-filter temp/station_north-america.pbf n/subway=yes -R -o temp/subway_na.pbf --overwrite
osmium cat temp/station_north-america.pbf -o temp/station_north-america.osm --overwrite
osmium cat temp/subway_na.pbf -o temp/subway_na.osm --overwrite
grep '<node' temp/subway_na.osm | awk -F ' id="' '{print $2}' | awk -F '"' '{print $1}' > temp/exclude_na_subway_ids.txt
awk '
BEGIN {
    while (getline < "temp/exclude_na_subway_ids.txt") exclude[$1] = 1;
    inNode = 0;
    print "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"; # Ensure the XML header is included
    print "<osm version=\"0.6\" generator=\"osmium/1.8.0\">"; # Adjust osmium version as needed
}
/^ *<node / {
    split($0, a, / id="|"/);
    nodeId = a[2];
    inNode = !(nodeId in exclude);
}
inNode { print }
/^ *<\/node>/ { inNode = 0; }
END {
    print "</osm>";
}
' temp/station_north-america.osm > temp/station_na-filtered.osm
osmium cat temp/station_na-filtered.osm -o temp/station_na-filtered.pbf
osmium export temp/station_na-filtered.pbf -o temp/station_north-america.geojson --overwrite
# load in DB
ogr2ogr -f MySQL MySQL:FACT_rail,host=$HOST,user=$USER,password=$PASSWORD ./temp/station_north-america.geojson -nln na_stations -update -overwrite -lco engine=Aria -t_srs EPSG:4326
ogr2ogr -f MySQL MySQL:FACT_rail,host=$HOST,user=$USER,password=$PASSWORD ./temp/line_north-america.geojson -nln na_lines -update -overwrite -lco engine=Aria -t_srs EPSG:4326
#clean up
rm -r temp
